%cyclotron
% Plots the trajectory of a particle in a cyclotron, assuming classical
% Physics, or if the magnetc field or cyclotron frequency is adjusted to
% account for relativistic effects.
%
% LAST UPDATED by Andry French November 2016

function cyclotron

%Magnetic field strength /T
B = 0.1;

%Gap between accelerating plates /m
d = 0.1;

%Charge of particle in cyclotron /C
qe = 1.602e-19;
q = 1*qe;

%Mass of particle in cyclotron /kg
m = 1.637e-27;

%Accelerating potential /V
%Note this is actually an AC signal, varying
%at the cyclotron frequency f_cy = B*q/(2*pi*m)
% Note fo no discharge in air, V/d must be less than 3e6
V = 100e3;

%Speed of light /ms^-1
c = 2.998e8;

%Define number of half loops
N = 50;

%Number of position points for each half loop
P = 200;

%Fontsize for graphs
fsize = 18;

%

%Calculate cyclotron frequency /Hz
f_cy = B*q/(2*pi*m);

%Step through loops and work out particle velocity
%hence circular path radius
u = 0;
r0 = m*sqrt( 2*q*V/m )/(B*q);
x = 0;
y = 0;
for n=1:N
    
    %Calculate velocity following boost
    v = sqrt( u^2 + 2*q*V/m );
    u = v;
    
    %Calculate radius of circular path
    r = m*v/(B*q);
    
    %Define vector of a half circle of polar angles
    theta = linspace(-pi/2,pi/2,P);
    
    %Which side?
    if (-1)^n == -1
        %Right side
        
        %Determine coordinates of centre of arc
        x0 = d/2;
        y0 = y(end)+r;
        
        %Define arc and add to existing coordinates
        x = [x,x0+r*cos(theta)];
        y = [y,y0+r*sin(theta)];
    else
        
        %Left side
        
        %Determine coordinates of centre of arc
        x0 = -d/2;
        y0 = y(end) - r;
        
        %Define arc and add to existing coordinates
        x = [x,x0-r*cos(theta)];
        y = [y,y0-r*sin(theta)];
    end
end

%Determine exit particle energy (classical) in MeV
E_MeV = 0.5*m*v^2 / (qe*1e6);

%Determine exit particle speed (as a fraction of the speed of light)
v_over_c = v/c;

%Plot path
figure('color',[1 1 1],'name','cyclotron')
plot(x,y);
axis equal
set(gca,'fontsize',fsize);
grid on;
xlabel('x /m','fontsize',fsize)
ylabel('y /m','fontsize',fsize)
filename = ['cyclotron B=',num2str(B),...
    'T V=',num2str(V/1e3),'kV f=',num2str(f_cy/1e6),'MHz'];
title({filename,['E = ',num2str(E_MeV),'MeV, v/c = ',num2str(v_over_c)]},'fontsize',fsize);
print(gcf,[filename,'.png'],'-dpng','-r300');

%End of code
